pub struct Search {
pub matches: Vec<usize>,
pub pattern: String,
pub start_idx: Option<usize>,
/* private fields */
}Fields
matches: Vec<usize>pattern: Stringstart_idx: Option<usize>Implementations
Sourceimpl Search
impl Search
Sourcepub fn search(
&mut self,
list: &[Utf32String],
direction: Direction,
) -> Option<usize>
pub fn search( &mut self, list: &[Utf32String], direction: Direction, ) -> Option<usize>
Searches for pattern in the list and the given direction. Returns the index of the first
match.
Examples
let mut search = Search::default();
search.pattern = String::from("ap");
let list = ["apple", "pineapple", "clementine"]
.iter()
.map(|s| Utf32String::from(*s))
.collect::<Vec<_>>();
let idx = search.search(&list, Direction::Forward);
assert_eq!(idx, Some(0));
let idx = search.search(&list, Direction::Backward);
assert_eq!(idx, Some(1));
search.start_idx = Some(0);
let idx = search.search(&list, Direction::Forward);
assert_eq!(idx, Some(1));Sourcepub fn next_match(&mut self) -> Option<&usize>
pub fn next_match(&mut self) -> Option<&usize>
Returns the index of the first match after start_idx or the first match if it is None.
Sourcepub fn previous_match(&mut self) -> Option<&usize>
pub fn previous_match(&mut self) -> Option<&usize>
Returns the index of the first match before start_idx or the last match if it is None.